/*
	In this example we will create a menu with several options available
*/

/* 
Util.spawnCommandLine("amixer -c 3 sset 'Analog Output',0 'Stereo Headphones FP' > /dev/null"); 

Import St because is the library that allow you to create UI elements */
const St = imports.gi.St;
const ExtensionUtils = imports.misc.extensionUtils;

/* Import Clutter because is the library that allow you to layout UI elements */
const Clutter = imports.gi.Clutter;
const Lang = imports.lang;
const Gtk = imports.gi.Gtk;
/*
Import Main because is the instance of the class that have all the UI elements
and we have to add to the Main instance our UI elements
*/
const Main = imports.ui.main;
const Gio = imports.gi.Gio;

const Me = imports.misc.extensionUtils.getCurrentExtension();
/*
Import PanelMenu and PopupMenu 
See more info about these objects in REFERENCE.md
*/
const PanelMenu = imports.ui.panelMenu;
const PopupMenu = imports.ui.popupMenu;

/*
Import Lang because we will write code in a Object Oriented Manner
*/
const GLib = imports.gi.GLib;
const Util = imports.misc.util;
const Convenience = Me.imports.convenience;
/*
In here we are creating a new Class named `PopupMenuExample`, it is derivated from `panelMenu.Button`
If you analize the class, you can see that:
	`Name:` is the same as the name class
	`Extends:` is the class you are extending from
	`_init: function(){}` is the constructor
	-destroy: function{}` is the destructor
	and you can add more functions to this class if you want to
*/
const PopupMenuExample = new Lang.Class({
	Name: 'PopupMenuExample',	// Class Name
	Extends: PanelMenu.Button,	// Parent Class
    
	// Constructor
	_init: function() {
		/* 
		This is calling the parent constructor
		1 is the menu alignment (1 is left, 0 is right, 0.5 is centered)
		`PopupMenuExample` is the name
		true if you want to create a menu automatically, otherwise false
		*/
		this.parent(1, 'PopupMenuExample', false);
 		// We are creating a box layout with shell toolkit
		let box = new St.BoxLayout();

		
		/*
		A new icon 'system-search-symbolic'.symbolic
		All icons are found in `/usr/share/icons/theme-being-used`
		In other tutorials we will teach you how to use your own icons

		The class 'system-status-icon` is very useful, remove it and restart the shell then you will see why it is useful here
		*/
			
		box.add(new St.Icon({
    		style_class: 'system-status-icon',
      		icon_name: 'xonar-icon-symbolic',
    	}));
			
		// A label expanded and center aligned in the y-axis
		let toplabel = new St.Label({ text: '',
			y_expand: true,
			y_align: Clutter.ActorAlign.CENTER });
		// We add the icon, the label and a arrow icon to the box
		box.add(toplabel);
		// We add the box to the button
		// It will be showed in the Top Panel
		//this.actor.remove_all_children();
		this.actor.add_child(box);
 		let activeState1 = GLib.spawn_command_line_sync('aplay -l')[1].toString().trim(); 		
		let ind = activeState1.search('Xonar DG');		
		Ncard = activeState1[ind-7];
		let s1 = GLib.spawn_command_line_sync("amixer -c "+Ncard+" sget 'Analog Output',0")[1].toString().trim().split('\n');
		let CurrentCap = s1[3].replace("Item0: '", "").replace("'", "").trim();		
		var i;
		for (i = 0; i < AItems.length; i++) {
  			let menuitem = new PopupMenu.PopupImageMenuItem(AItems[i], AItemsIcon[i]);
			menuitem.connect('activate', Lang.bind(this, this._TermLaunch, i));			
			if (CurrentCap == AItems[i]) menuitem.setOrnament(PopupMenu.Ornament.CHECK);
			this.menu.addMenuItem(menuitem);			
		}
		this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
		let menuitem = new PopupMenu.PopupMenuItem('Alsamixer');
		menuitem.connect('activate', function(){
			Util.spawnCommandLine("gnome-terminal -e 'alsamixer -c "+Ncard+"'");
		});
		this.menu.addMenuItem(menuitem);	

		/*
		With 'open-state-changed' on a popupmenu we can know if the menu is being shown
		We will just show the submenu menu items automatically, (by default it is not shown)
		*/
		this.menu.connect('open-state-changed', Lang.bind(this, function(){
			popupMenuExpander.setSubmenuShown(true);
		}));

	},
	
	_TermLaunch: function(actor, event, runcmd) {
  		Util.spawnCommandLine("amixer -c "+Ncard+" sset 'Analog Output',0 '"+AItems[runcmd]+"' > /dev/null");
		//Main.notify(Ncard, Ncard);
		/*let box = new St.BoxLayout();
		let icon =  new St.Icon({ icon_name: icon2, style_class: 'system-status-icon'});
		let toplabel = new St.Label({ text: ' Xonar DG ',
			y_expand: true,
			y_align: Clutter.ActorAlign.CENTER });
		box.add(icon);
		box.add(toplabel);
		this.actor.remove_all_children();
		this.actor.add_child(box);*/
		//let menuitem4 = new PopupMenu.PopupImageMenuItem('Multichannel1111', 'audio-speakers-symbolic');
		
		let children = this.menu._getMenuItems();
		//item.setOrnament(PopupMenu.Ornament.CHECK);
        for (let i = 0; i < 3; i++) {
            let item = children[i];
            item.setOrnament(PopupMenu.Ornament.NONE);
        }
		let item = children[runcmd];
		item.setOrnament(PopupMenu.Ornament.CHECK);
		
  	},
	
	

	/*
	We destroy the button
	*/
	destroy: function() {
		/*
		This call the parent destroy function
		*/
		this.parent();
	}
});


/* Global variables for use as button to click */
let button;
let Ncard;
let AItems = ["Stereo Headphones FP", "Stereo Headphones","Multichannel"]
let AItemsIcon = ['audio-headset-symbolic', 'audio-headphones-symbolic', 'audio-speakers-symbolic'];

/*
This is the init function, here we have to put our code to initialize our extension.
we have to be careful with init(), enable() and disable() and do the right things here.
In this case we will do nothing
*/
function init() {
 Convenience.initIcons();
}

/*
We have to write here our main extension code and the things that actually make works the extension(Add ui elements, signals, etc).
*/
function enable() {
	/* Create a new object button from class PopupMenuExample */
	button = new PopupMenuExample;

	/* 
	In here we are adding the button in the status area
	- `PopupMenuExample` is tha role, must be unique. You can access it from the Looking Glass  
	in 'Main.panel.statusArea.PopupMenuExample`
	- button is and instance of panelMenu.Button
	- 0 is the position
	- `right` is the box where we want our button to be displayed (left/center/right)
	 */
	Main.panel.addToStatusArea('PopupMenuExample', button, 0, 'right');
}

/*
We have to delete all conections and things from our extensions, to let the system how it is before our extension. So
We have to unconnect the signals we connect, we have to delete all UI elements we created, etc.
*/
function disable() {
	/* 
	We call the destroy function inside the object button
	therefore the button is remove from the panel
	*/
	button.destroy();	
}